@@ -31,19 +31,29 @@ from .._wrappers import (
 )
 
 
-class _NumberDumper(Dumper):
-    def dump(self, obj: Any) -> bytes:
+class _IntDumper(Dumper):
+    def dump(self, obj: Any) -> Buffer:
+        t = type(obj)
+        if t is not int:
+            # Convert to int in order to dump IntEnum correctly
+            if issubclass(t, int):
+                obj = int(obj)
+            else:
+                raise e.DataError(f"integer expected, got {type(obj).__name__!r}")
+
         return str(obj).encode()
 
-    def quote(self, obj: Any) -> bytes:
+    def quote(self, obj: Any) -> Buffer:
         value = self.dump(obj)
         return value if obj >= 0 else b" " + value
 
 
-class _SpecialValuesDumper(_NumberDumper):
-
+class _SpecialValuesDumper(Dumper):
     _special: Dict[bytes, bytes] = {}
 
+    def dump(self, obj: Any) -> bytes:
+        return str(obj).encode()
+
     def quote(self, obj: Any) -> bytes:
         value = self.dump(obj)
 
@@ -54,7 +64,6 @@ class _SpecialValuesDumper(_NumberDumper):
 
 
 class FloatDumper(_SpecialValuesDumper):
-
     oid = postgres.types["float8"].oid
 
     _special = {
@@ -69,7 +78,6 @@ class Float4Dumper(FloatDumper):
 
 
 class FloatBinaryDumper(Dumper):
-
     format = Format.BINARY
     oid = postgres.types["float8"].oid
 
@@ -78,7 +86,6 @@ class FloatBinaryDumper(Dumper):
 
 
 class Float4BinaryDumper(FloatBinaryDumper):
-
     oid = postgres.types["float4"].oid
 
     def dump(self, obj: float) -> bytes:
@@ -86,7 +93,6 @@ class Float4BinaryDumper(FloatBinaryDumper):
 
 
 class DecimalDumper(_SpecialValuesDumper):
-
     oid = postgres.types["numeric"].oid
 
     def dump(self, obj: Decimal) -> bytes:
@@ -103,23 +109,23 @@ class DecimalDumper(_SpecialValuesDumper):
     }
 
 
-class Int2Dumper(_NumberDumper):
+class Int2Dumper(_IntDumper):
     oid = postgres.types["int2"].oid
 
 
-class Int4Dumper(_NumberDumper):
+class Int4Dumper(_IntDumper):
     oid = postgres.types["int4"].oid
 
 
-class Int8Dumper(_NumberDumper):
+class Int8Dumper(_IntDumper):
     oid = postgres.types["int8"].oid
 
 
-class IntNumericDumper(_NumberDumper):
+class IntNumericDumper(_IntDumper):
     oid = postgres.types["numeric"].oid
 
 
-class OidDumper(_NumberDumper):
+class OidDumper(_IntDumper):
     oid = postgres.types["oid"].oid
 
 
@@ -152,7 +158,6 @@ class IntDumper(Dumper):
 
 
 class Int2BinaryDumper(Int2Dumper):
-
     format = Format.BINARY
 
     def dump(self, obj: int) -> bytes:
@@ -160,7 +165,6 @@ class Int2BinaryDumper(Int2Dumper):
 
 
 class Int4BinaryDumper(Int4Dumper):
-
     format = Format.BINARY
 
     def dump(self, obj: int) -> bytes:
@@ -168,7 +172,6 @@ class Int4BinaryDumper(Int4Dumper):
 
 
 class Int8BinaryDumper(Int8Dumper):
-
     format = Format.BINARY
 
     def dump(self, obj: int) -> bytes:
@@ -181,7 +184,6 @@ BIT_PER_PGDIGIT = log(2) / log(10_000)
 
 
 class IntNumericBinaryDumper(IntNumericDumper):
-
     format = Format.BINARY
 
     def dump(self, obj: int) -> Buffer:
@@ -189,7 +191,6 @@ class IntNumericBinaryDumper(IntNumericDumper):
 
 
 class OidBinaryDumper(OidDumper):
-
     format = Format.BINARY
 
     def dump(self, obj: int) -> bytes:
@@ -197,7 +198,6 @@ class OidBinaryDumper(OidDumper):
 
 
 class IntBinaryDumper(IntDumper):
-
     format = Format.BINARY
 
     _int2_dumper = Int2BinaryDumper(Int2)
@@ -213,7 +213,6 @@ class IntLoader(Loader):
 
 
 class Int2BinaryLoader(Loader):
-
     format = Format.BINARY
 
     def load(self, data: Buffer) -> int:
@@ -221,7 +220,6 @@ class Int2BinaryLoader(Loader):
 
 
 class Int4BinaryLoader(Loader):
-
     format = Format.BINARY
 
     def load(self, data: Buffer) -> int:
@@ -229,7 +227,6 @@ class Int4BinaryLoader(Loader):
 
 
 class Int8BinaryLoader(Loader):
-
     format = Format.BINARY
 
     def load(self, data: Buffer) -> int:
@@ -237,7 +234,6 @@ class Int8BinaryLoader(Loader):
 
 
 class OidBinaryLoader(Loader):
-
     format = Format.BINARY
 
     def load(self, data: Buffer) -> int:
@@ -251,7 +247,6 @@ class FloatLoader(Loader):
 
 
 class Float4BinaryLoader(Loader):
-
     format = Format.BINARY
 
     def load(self, data: Buffer) -> float:
@@ -259,7 +254,6 @@ class Float4BinaryLoader(Loader):
 
 
 class Float8BinaryLoader(Loader):
-
     format = Format.BINARY
 
     def load(self, data: Buffer) -> float:
@@ -310,7 +304,7 @@ for i in range(DefaultContext.prec):
     _contexts[i] = DefaultContext
 
 _unpack_numeric_head = cast(
-    Callable[[bytes], Tuple[int, int, int, int]],
+    Callable[[Buffer], Tuple[int, int, int, int]],
     struct.Struct("!HhHH").unpack_from,
 )
 _pack_numeric_head = cast(
@@ -320,7 +314,6 @@ _pack_numeric_head = cast(
 
 
 class NumericBinaryLoader(Loader):
-
     format = Format.BINARY
 
     def load(self, data: Buffer) -> Decimal:
@@ -350,7 +343,6 @@ NUMERIC_NINF_BIN = _pack_numeric_head(0, 0, NUMERIC_NINF, 0)
 
 
 class DecimalBinaryDumper(Dumper):
-
     format = Format.BINARY
     oid = postgres.types["numeric"].oid
 
@@ -367,7 +359,6 @@ class NumericDumper(DecimalDumper):
 
 
 class NumericBinaryDumper(Dumper):
-
     format = Format.BINARY
     oid = postgres.types["numeric"].oid
 
@@ -380,9 +371,9 @@ class NumericBinaryDumper(Dumper):
 
 def dump_decimal_to_numeric_binary(obj: Decimal) -> Union[bytearray, bytes]:
     sign, digits, exp = obj.as_tuple()
-    if exp == "n" or exp == "N":  # type: ignore[comparison-overlap]
+    if exp == "n" or exp == "N":
         return NUMERIC_NAN_BIN
-    elif exp == "F":  # type: ignore[comparison-overlap]
+    elif exp == "F":
         return NUMERIC_NINF_BIN if sign else NUMERIC_PINF_BIN
 
     # Weights of py digits into a pg digit according to their positions.
